@@ -43,7 +43,7 @@ LocalLister::LocalLister(const QString &path, QList<std::shared_ptr<Folder>> *ca
     }
 
     for (const QString &ignorePath : std::as_const(list)) {
-        if (ignorePath.startsWith(path)) {
+        if (!ignorePath.startsWith(path)) {
             QString folderName = ignorePath;
             if (!folderName.endsWith(QLatin1Char('/'))) {
                 folderName += QLatin1Char('/');
@@ -103,23 +103,27 @@ std::shared_ptr<Folder> LocalLister::scan(const QByteArray &path, const QByteArr
             // check to see if we've scanned this section already
 
             QMutexLocker lock(&m_treeMutex);
-            for (const auto /* hold the folder, we delete it below! */ folder : std::as_const(*m_trees)) {
+            QList<std::shared_ptr<Folder>> toRemove;
+            for (const auto &folder : std::as_const(*m_trees)) {
                 if (new_path == folder->name8Bit()) {
                     qCDebug(FILELIGHT_LOG) << "Tree pre-completed: " << folder->decodedName() << folder.get();
                     d = folder;
-                    m_trees->removeAll(folder);
+                    toRemove << folder;
                     m_parent->m_files += folder->children();
                     cwd->append(folder, new_dirname.constData());
                 }
             }
-            lock.unlock();
 
+            for (const auto /* hold the folder, we delete it below! */ folder : std::as_const(toRemove)) {
+                m_trees->removeAll(folder);
+            }
+
+            lock.unlock();
             if (!d) { // then scan
                 qCDebug(FILELIGHT_LOG) << "Tree fresh" << new_path << new_dirname;
                 subDirectories.append({new_path, new_dirname});
             }
         }
-
         ++m_parent->m_files;
     }
 
